==> edar-0.1.tar.gz: edar-0.1/setup.py <==
from distutils.core import setup

setup(
  name = 'edar',         # How you named your package folder (MyLib)
  packages = ['edar'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Exploratory data analysis reporter for jupyter notebook',   # Give a short description about your library
  author = 'Joppe Vos',                   # Type in your name
  author_email = 'joppe.vos@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/joppevos/Edas',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/joppevos/Edas/archive/v0.01.tar.gz',    # I explain this later on
  keywords = ['data', 'analytics', 'explorer'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'seaborn',
          'matplotlib',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> edar-0.2.tar.gz: edar-0.2/setup.py <==
from distutils.core import setup

setup(
  name = 'edar',         # How you named your package folder (MyLib)
  packages = ['edar'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Exploratory data analysis reporter for jupyter notebook',   # Give a short description about your library
  author = 'Joppe Vos',                   # Type in your name
  author_email = 'joppe.vos@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/joppevos/Edar',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/joppevos/Edar/archive/v0.02.tar.gz',    # I explain this later on
  keywords = ['data', 'analytics', 'explorer'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'seaborn',
          'matplotlib',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
